from elasticsearch import Elasticsearch
import glob

es_hosts = ["es-oscars-01.vgt.vito.be", "es-oscars-02.vgt.vito.be", "es-oscars-03.vgt.vito.be"]
es = Elasticsearch(es_hosts)
es_scroll_timeout = "1m"

producttypes = [
    {
        "name": "S1 GRD",
        "index": "oscars_cgss1_grd_l1",
        "glob": "/data/MTDA/CGS_S1/CGS_S1_GRD_L1/IW/HR/DV/*/*/*/*/*.xml"
    },
    {
        "name": "S1 SLC",
        "index": "oscars_cgss1_slc_l1",
        "glob": "/data/MTDA/CGS_S1/CGS_S1_SLC_L1/IW/DV/*/*/*/*/*.xml"
    },
    {
        "name": "S1 SIGMA0",
        "index": "oscars_cgss1_grd_sigma0_l1",
        "glob": "/data/MTDA/CGS_S1/CGS_S1_GRD_SIGMA0_L1/*/*/*/*/*.xml"
    }
]

for pt in producttypes:
    print("=== {} ===".format(pt['name']))

    on_disk = glob.glob(pt['glob'])
    print("MTDA: {}".format(len(on_disk)))

    es_result = es.search(index=pt['index'], size=100, scroll=es_scroll_timeout)
    print("ES: {}".format(es_result['hits']['total']['value']))

    # check which products are missing
    es_metadata = set()
    while es_result['hits']['hits']:
        scroll_id = es_result['_scroll_id']
        hits = es_result['hits']['hits']

        es_metadata.update({h['_source']['properties']['links']['alternates'][0]['href'].split("file://", 1)[-1] for h in hits})

        es_result = es.scroll(scroll_id=scroll_id, scroll=es_scroll_timeout)

    missing_oscars = set(on_disk).difference(es_metadata)
    if missing_oscars:
        print("Missing products in OSCARS: {}".format(missing_oscars))

    missing_disk = es_metadata.difference(set(on_disk))
    if missing_disk:
        print("Missing products on disk: {}".format(missing_disk))