"""
Created on 30 June 2019

@author: Tonneau Stephane
"""

import time
import logging
from oscars_mgmnt.utils.common import OutputWriter

STATWRITER_LOGGER = logging.getLogger('StatisticsWriter')


class StatisticsWriter(OutputWriter):
    '''Writer that only collects statistics on file ingestion.'''

    def __init__(self):
        """ Initialisator of the class.
        """
        OutputWriter.__init__(self)
        self.cnt = 0
        self.dfcnt = 0
        self.dftim = 10
        self.oldtime = time.time()
        self.start = time.time()
        STATWRITER_LOGGER.info("Start : %s", time.strftime("%Y-%m-%dT%H:%M:%SZ",
                                                           time.localtime(self. start)))

    def output(self, uid, content):
        """ extracts statistic information from the message.

        :param uid: a unique reference
        :type uid: a string
        :param content: a string containing the metadata content to save.
        :type content: a string
        """
        self.cnt = self.cnt + 1
        self.dfcnt = self.dfcnt + 1
        if (time.time() - self.oldtime) > self.dftim:
            STATWRITER_LOGGER.info("  treated : %s -> speed : %s product/s",
                                   str(self.dfcnt), str(self.dfcnt / self.dftim))
            self.oldtime = time.time()
            self.dfcnt = 0

    def flush(self):
        """ flushes the computed statistics.

        """
        STATWRITER_LOGGER.info("End   : %s", time.strftime("%Y-%m-%dT%H:%M:%SZ"))
        STATWRITER_LOGGER.info("      -> time : %s sec", str(time.time()-self.start))
        STATWRITER_LOGGER.info("Count : %s", str(self.cnt))
        STATWRITER_LOGGER.info("Speed : %s product/s",
                               str(self.cnt / (time.time()-self.start)))
